function [keff,s2keff] = keff_SIZ(V0,U,sic,waterT,airT,varargin),

% function [keff,s2keff] = keff_SIZ(V0,U,sic,waterT,airT,varargin),
%
% keff_SIZ: The effective gas transfer velocity in the sea ice zone.
%
% INPUT:  
%       V0 = ice velocity (m/s)
%       U = wind speed (not vector) in m/s
%       sic = sea ice concentration (%)
%       waterT = water temp in deg C
%       airT = air temp in deg C.
%
% OUTPUT:
%   keff = effective gas transfer velocity in sea ice covered waters  [m/d]
%
% DEPENDENCIES:  
%   These routines require the Gibbs Seawater toolbox: 
%   http://www.teos-10.org/
% 
% AUTHOR:  Brice Loose (osoberlice@gmail.com)
%
% REFERENCE:
%       Loose et al., (2013), "A parameter model of gas exchange for the 
%       seasonal sea ice zone", Ocean Sci. Discuss., 10(4), 1169-1204.
%
% DISCLAIMER:
%    This software is provided "as is" without warranty of any kind.  
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

%- functions used:
%- sw_cp, sw_alpha, sw_beta, satvap, U0, S_solve, sw_bfrq, sw_freezetemp,
%- floe_dimension.m


if nargin > 5,
    hum = varargin{1};
else
    hum = 273.16./8.3141./satvap(waterT)./1e2*.06;
end
if nargin > 6,
    %- Set the Mixed-layer depth (m) if it has not been specified.
    mld = varargin{2};
else
    mld = 30;
end
if nargin > 7
    %- Set the salinity if it has not been specified.
    waterS = varargin{3};
else
    waterS = 32;
end




%- convert to Kelvin
waterT = waterT+273.16;
airT = airT+273.16;

%--- COEFICIENTS
g = 9.8;  
cd = 1.5e-3;    %- Air-water drag coefficient
vis = 1.787e-6; %- Kinematic viscosity m2/s
Sc = 660;       %- Schmidt Number (unitless)
n = 0.5;        %- Schmidt Number exponent
z = 2;
z0 = .01;       %- Roughness length
acp  = 1.005e3; %- Specific heat of air (J/kg/K)
Lh = 2.26e6;    %- Latent heat of melting (J/kg)
rho_a = 1.013e5/287.058./(airT);
%rho_w = sw_dens(airT-273.16, waterT-273.16,0);
rho_w = gsw_rho(airT-273.16, waterT-273.16,0);

plt = 'y';

%- SIC (as decimal)
Ai = sic'./100;

%% --------------------------------------------------------------------- %%
%----------------- (1) BUOYANCY FLUX CALCULATION -------------------------%
%-------------------------------------------------------------------------%

%- J_b^o = g*Ch*U*(Tw-T)/T -- (m2/s3)


%- heat capacity and expansion/contraction coefs.
wcp  = sw_cp(waterS,waterT-273.16,0);
%wcp = gsw_cp_t_exact(waterS,waterT-273.16,0);
alpha = sw_alpha(waterS,waterT-273.16,0);
%alpha = gsw_alpha(waterS,waterT-273.16,0);
beta = sw_beta(waterS,waterT-273.16,0);
%beta = gsw_beta(waterS,waterT-273.16,0);

%- precalculate u*0 because we need for ice-water
us = V0.*.41/log(z/z0);
sens_hf = rho_a*acp*cd.*abs(U).*(waterT-airT);
Jb_sens = 9.8*alpha.*sens_hf./rho_a./acp;



%--- Andreas and Murphy (1986), "Bulk transfer coefficients for heat and 
%- momentum over leads and polynyas". JPO, V. 16, 1875-1883.
%- Qs = Qsat(ts).  Then Qr is "ref" specific humidity at same height as
%- U.
%- Units are kg-w/m3-air
%- pv = nrt --- n/v(mol/m3)=rt/p.  n/v*.06kg/mol
Qs = 273.16./8.3141./satvap(waterT-273.15)./1e2*.06;

%- Buoyancy flux due to bulk evaporative Latent heat flux.
JqLf = Lh.*cd.*abs(U).*(Qs-hum).*rho_a;
Jb_Lf = g.*alpha.*JqLf./rho_a./acp;

%- Buoyancy flux due to salinification from evaporation
Jb_salt = g.*beta.*waterS.*(JqLf./Lh)./1e3;


%- Buoyancy flux from ice melt/freeze;
%- Based on interface fluxes using the 3 equation solution (IOBL, 6.9). 
%- <w'T'>_0 = w_0*Q_L + q
%- <w'S'>_0 = w_0*(Sice-S0)
%-
%- Reference: McPhee (2010) Air-ice-Ocean Interaction, Springer.
a.us0 = us;
a.alpha_h = .0057;
a.alpha_S = 4e-4;
a.Tml = waterT-273.16;
a.Sml = waterS;
a.Sice = 6;     %- ice salinity
a.wperc = 1e-7;

%- calculate ice temperature as half way between water and air temp.
Tice = nanmean([tfreeze(waterS,0)+273.16 airT],2); 
%Tice = nanmean([gsw_t_freezing(waterS,0)+273.16 airT],2);
%- Kice ~ Kfresh + beta*Sice/Tice
Kice = 2.04 + 0.117*a.Sice./Tice;

a.Hup_ice = -Kice.*(Tice-waterT);

b = S_solve(a);

%- Output b.wb0 is already in W/kg or m2/s3.
Jb_ice = b.wb0;


%- Positive Flux out of the ocean, corresponds to a loss of buoyancy
%- This is why first terms have "negative" signs in front.
Jb = nansum([-(1-Ai).*Jb_sens,-(1-Ai).*Jb_Lf, (1-Ai).*Jb_salt, +Ai.*Jb_ice],2);


%% --------------------------------------------------------------------- %%
%----------------- (2) SHEAR CALCULATION ---------------------------------%
%-------------------------------------------------------------------------%

%- CALC tau_skin-iw the ice/water skin friction using the Rossby similarity
%- theorem:  Vo/u* = 1/k(log(u*/fzo) - A + iB)
%--------------------------------------------
%- Reference: McPhee (2010) Air-ice-Ocean Interaction, Springer.

rho_a = 1.013e5/287.058./(airT);
tau_aw = (1-.14)*rho_a.*cd.*(U.^2);
us_aw = sqrt(tau_aw/rho_w);

% now set roughness to 1 cm, Coriolis parameter for 75N
kappa = .41;
f=1.4e-4;
Rostar=b.us0./f./z0;

% compute the Obukhov length
%L=b.us0.^3./kappa./b.wb0;
L=b.us0.^3./kappa./Jb;
Lo = L;
L(L<1) = 1;

% mu* is ratio of planetary to Obukhov scales
mustar=b.us0./f./L;

%- When mustar, stability parameter is negative, stratification is not
%- affecting surface shear.
mustar(mustar<0)=0;

[Und,etastar,A,B]=U0(Rostar,mustar);

Vstable=b.us0.*Und./etastar;
Vsr = real(Vstable).*kappa./(log(Rostar)-A);
Vsi = imag(Vstable).*kappa./(log(Rostar)-A-B);
us_iw = sqrt(Vsr.^2+Vsi.^2);
tau_iw = us_iw.^2.*rho_w;


%- CALC FORM DRAG FROM ESTIMATE OF SEA ICE COVER AND DRIFT VELOCITY -%
%-- This takes into account the recognition that the flow size
%- distribution is a pmf w.r.t. sea ice concentration.

%- Calculate L from SIC:
[L, dia, PMF] = floe_dimension(sic);
dia = dia*1000;

%- Form drag
tau_f =  0.5*rho_w.*(2.5./L').*V0.^2;
%- Friction velocity from form drag
us_f = sqrt(tau_f./rho_w);


%- FINAL SHEAR-BASED CALCULATIONS ---%
us_tot = sqrt(Ai.*(us_f.^2 + us_iw.^2) + us_aw.^2.*(1-Ai));



%- make a logical index for Obukhov convection criteria
convect = mld'./z./Lo;
use = convect<1;
eps1 = us_tot.^3/.41/z;

%- Calculate Epsilon from heat flux and shear.
%- Reference: 
eps_Jb = abs(.58*.84*Jb.*use);
eps_sh = .84*1.76*eps1;


%- calculate k from shear (visc. (m2/s), eps (m2/s3)=> m/s
%- multiply by 86400 to get m/d.
k = .419*Sc^(-n).*(vis.*(nansum([eps_Jb,eps_sh],2))).^.25*86400;
keff = (1-Ai).*k;


%% --------------------------------------------------------------------- %%
%---------- (3) CAPILLARY-GRAVITY WAVE CALCULATION -----------------------%
%-------------------------------------------------------------------------%
%- Calculate the mean-square wave slope from the windspeed;

pp2 = [0.0000   -0.0002    0.0015   -0.0012];
s2 = polyval(pp2,U);

%- k from wave slope in m/d
s2k = 1.4*.24 + 7.6e5.*(s2).^2.*.24;

s2keff = (1-Ai).*s2k;


%-------------------------------------------------------------------------%
%% PLOT %%

if plt == 'y',
    
    figure(33); clf;
    ax(1) = plot((1-Ai),keff,'k','linewidth',2);
    hold on;
    ax(2) = plot((1-Ai),s2keff,'r','linewidth',2);
    
    leg = legend(ax,'k_{eff} from ice effects','k_{eff} from capillary-gravity waves',2);
    set(leg,'box','off','fontsize',12);
    ylabel('k_{eff} (m/d)');  xlabel('fraction of open water (f)');
end


